package com.usky.fire.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.usky.common.core.bean.CommonPage;
import com.usky.common.security.utils.SecurityUtils;
import com.usky.fire.domain.PatrolInspectionEvent;
import com.usky.fire.domain.PatrolInspectionPersonnel;
import com.usky.fire.domain.PatrolInspectionPlanSchedule;
import com.usky.fire.mapper.PatrolInspectionEventMapper;
import com.usky.fire.service.PatrolInspectionEventService;
import com.usky.common.mybatis.core.AbstractCrudService;
import com.usky.fire.service.PatrolInspectionPersonnelService;
import com.usky.fire.service.PatrolInspectionPlanScheduleService;
import com.usky.fire.service.vo.PatrolInspectionPlanRequestVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 * 事件管理表 服务实现类
 * </p>
 *
 * @author han
 * @since 2024-05-09
 */
@Service
public class PatrolInspectionEventServiceImpl extends AbstractCrudService<PatrolInspectionEventMapper, PatrolInspectionEvent> implements PatrolInspectionEventService {
    @Autowired
    private PatrolInspectionPlanScheduleService patrolInspectionPlanScheduleService;
    @Autowired
    private PatrolInspectionPersonnelService patrolInspectionPersonnelService;

    @Override
    public CommonPage<PatrolInspectionEvent> patrolInspectionEventList(PatrolInspectionPlanRequestVO requestVO){
        Integer current = requestVO.getPageNum();
        Integer size = requestVO.getPageSize();
        IPage<PatrolInspectionEvent> page = new Page<>(current,size);
        LambdaQueryWrapper<PatrolInspectionEvent> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(requestVO.getId() != null,PatrolInspectionEvent::getId,requestVO.getId())
                .like(StringUtils.isNotBlank(requestVO.getPersonnelName()),PatrolInspectionEvent::getPersonnelName,requestVO.getPersonnelName())
                .like(StringUtils.isNotBlank(requestVO.getEventName()),PatrolInspectionEvent::getEventName,requestVO.getEventName())
                .eq(requestVO.getHandleStatus() != null,PatrolInspectionEvent::getHandleStatus,requestVO.getHandleStatus())
                .eq(StringUtils.isNotBlank(requestVO.getDeviceId()),PatrolInspectionEvent::getDeviceId,requestVO.getDeviceId())
                .eq(requestVO.getEventLevel() != null,PatrolInspectionEvent::getEventLevel,requestVO.getEventLevel())
                .eq(PatrolInspectionEvent::getTenantId, SecurityUtils.getTenantId())
                .orderByDesc(PatrolInspectionEvent::getId);
        page = this.page(page,queryWrapper);

        return new CommonPage<>(page.getRecords(),page.getTotal(),size,current);
    }

    @Override
    public void add(PatrolInspectionEvent patrolInspectionEvent){
        Integer planId = patrolInspectionEvent.getPlanId();
        LambdaQueryWrapper<PatrolInspectionPlanSchedule> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(PatrolInspectionPlanSchedule::getPlanId,planId);
        List<PatrolInspectionPlanSchedule> list = patrolInspectionPlanScheduleService.list(queryWrapper);
        if(list.size() > 0){
            Integer personnelId = list.get(0).getPersonnelId();
            LambdaQueryWrapper<PatrolInspectionPersonnel> queryWrapper1 = Wrappers.lambdaQuery();
            queryWrapper1.eq(PatrolInspectionPersonnel::getId,personnelId);
            PatrolInspectionPersonnel one = patrolInspectionPersonnelService.getOne(queryWrapper1);

            patrolInspectionEvent.setPersonnelId(personnelId);
            patrolInspectionEvent.setPersonnelName(one.getFullName());
        }
        patrolInspectionEvent.setHandleStatus(0);
        patrolInspectionEvent.setTenantId(SecurityUtils.getTenantId());
        patrolInspectionEvent.setCreateBy(SecurityUtils.getUsername());
        patrolInspectionEvent.setCreateTime(LocalDateTime.now());

        this.save(patrolInspectionEvent);
    }

    @Override
    public void edit(PatrolInspectionEvent patrolInspectionEvent){
        patrolInspectionEvent.setHandleStatus(1);
        patrolInspectionEvent.setHandleName(SecurityUtils.getUsername());
        patrolInspectionEvent.setHandleTime(LocalDateTime.now());
        this.updateById(patrolInspectionEvent);

    }

}
